@@ -1,20 +1,21 @@
-// Source file for evolvotron
-// Copyright (C) 2007 Tim Day
-/*
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*/
+/**************************************************************************/
+/*  Copyright 2009 Tim Day                                                */
+/*                                                                        */
+/*  This file is part of Evolvotron                                       */
+/*                                                                        */
+/*  Evolvotron is free software: you can redistribute it and/or modify    */
+/*  it under the terms of the GNU General Public License as published by  */
+/*  the Free Software Foundation, either version 3 of the License, or     */
+/*  (at your option) any later version.                                   */
+/*                                                                        */
+/*  Evolvotron is distributed in the hope that it will be useful,         */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
+/*  GNU General Public License for more details.                          */
+/*                                                                        */
+/*  You should have received a copy of the GNU General Public License     */
+/*  along with Evolvotron.  If not, see <http://www.gnu.org/licenses/>.   */
+/**************************************************************************/
 
 /*! \file
   \brief Implementation of class EvolvotronMain.
@@ -25,7 +26,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "evolvotron_main.h"
 
-#include "args.h"
 #include "dialog_about.h"
 #include "dialog_help.h"
 #include "dialog_mutation_parameters.h"
@@ -191,10 +191,18 @@ EvolvotronMain::EvolvotronMain
  bool autocool,
  bool jitter,
  uint multisample_level,
- bool function_debug_mode
+ bool function_debug_mode,
+ bool linear_zsweep,
+ bool spheremap,
+ const std::vector<std::string>& startup_filenames,
+ bool startup_shuffle
  )
   :QMainWindow(parent)
   ,_history(new EvolvotronMain::History(this))
+  ,_linear_zsweep(linear_zsweep)
+  ,_spheremap(spheremap)
+  ,_startup_filenames(startup_filenames)
+  ,_startup_shuffle(startup_shuffle)
   ,_mutation_parameters(time(0),autocool,function_debug_mode,this)
   ,_render_parameters(jitter,multisample_level,this)
   ,_statusbar_tasks_main(0)
@@ -680,8 +688,7 @@ void EvolvotronMain::reset(MutatableImageDisplay* display)
     }
 
   history().replacing(display);
-  //! \todo sinz and spheremap should be obtained from mutation parameters
-  const boost::shared_ptr<const MutatableImage> image_function(new MutatableImage(root,!Args::global().option("-linz"),Args::global().option("-spheremap"),false));
+  const boost::shared_ptr<const MutatableImage> image_function(new MutatableImage(root,!_linear_zsweep,_spheremap,false));
   display->image_function(image_function,true);
 }
 
@@ -723,14 +730,24 @@ void EvolvotronMain::reset(bool reset_mutation_parameters,bool clear_locks)
       _mutation_parameters.autocool_generations(0);
     }
 
-  for (std::vector<MutatableImageDisplay*>::iterator it=displays().begin();it!=displays().end();it++)
-    {
-      if (clear_locks)
-	(*it)->lock(false,false);  // lock method mustn't make it's own history recording
+  for (size_t i=0;i<displays().size();++i)
+  {
+    if (clear_locks)
+      displays()[i]->lock(false,false);  // lock method mustn't make it's own history recording
+  }
 
-      if (!(*it)->locked())
-	reset(*it);
+  if (_startup_shuffle) {
+    std::random_shuffle(_startup_filenames.begin(),_startup_filenames.end());
+  }
+
+  for (size_t i=0;i<displays().size();++i) {
+    if (!displays()[i]->locked()) {
+      if (i<_startup_filenames.size())
+	displays()[i]->load_function_file(_startup_filenames[i].c_str());
+      else
+	reset(displays()[i]);
     }
+  }
 
   last_spawned_image(boost::shared_ptr<const MutatableImage>(),&EvolvotronMain::spawn_normal);
 
