@@ -1,20 +1,21 @@
-// Source file for evolvotron
-// Copyright (C) 2007 Tim Day
-/*
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*/
+/**************************************************************************/
+/*  Copyright 2009 Tim Day                                                */
+/*                                                                        */
+/*  This file is part of Evolvotron                                       */
+/*                                                                        */
+/*  Evolvotron is free software: you can redistribute it and/or modify    */
+/*  it under the terms of the GNU General Public License as published by  */
+/*  the Free Software Foundation, either version 3 of the License, or     */
+/*  (at your option) any later version.                                   */
+/*                                                                        */
+/*  Evolvotron is distributed in the hope that it will be useful,         */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
+/*  GNU General Public License for more details.                          */
+/*                                                                        */
+/*  You should have received a copy of the GNU General Public License     */
+/*  along with Evolvotron.  If not, see <http://www.gnu.org/licenses/>.   */
+/**************************************************************************/
 
 /*! \file 
   \brief Interface for class EvolvotronMain.
@@ -131,6 +132,22 @@ class EvolvotronMain : public QMainWindow
   //! Instance of History object to track activity.
   std::auto_ptr<History> _history;
 
+  //! Sweep z linearly through animations
+  /*! \todo Move to mutation or render paraemeters ?
+   */
+  const bool _linear_zsweep;
+
+  //! Generate spheremaps
+  /*! \todo Move to mutation or render paraemeters ?
+   */
+  const bool _spheremap;
+
+  //! Name of files to load on a reset.
+  std::vector<std::string> _startup_filenames;
+
+  //! Whether to shuffle startup files (if any).
+  const bool _startup_shuffle;
+  
   //! Instance of mutation parameters for the app
   /*! This used to be held by DialogMutationParameters, but now we want to share it around a bit
     (although modifications should always be via the dialog slots, to keep the dialogs up to date)
@@ -293,7 +310,11 @@ class EvolvotronMain : public QMainWindow
      bool autocool,
      bool jitter,
      uint multisample_level,
-     bool function_debug_mode
+     bool function_debug_mode,
+     bool linear_zsweep,
+     bool spheremap,
+     const std::vector<std::string>& startup_filenames,
+     bool startup_shuffle
      );
 
   //! Destructor.
