@@ -1,20 +1,21 @@
-// Source file for evolvotron
-// Copyright (C) 2007 Tim Day
-/*
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*/
+/**************************************************************************/
+/*  Copyright 2009 Tim Day                                                */
+/*                                                                        */
+/*  This file is part of Evolvotron                                       */
+/*                                                                        */
+/*  Evolvotron is free software: you can redistribute it and/or modify    */
+/*  it under the terms of the GNU General Public License as published by  */
+/*  the Free Software Foundation, either version 3 of the License, or     */
+/*  (at your option) any later version.                                   */
+/*                                                                        */
+/*  Evolvotron is distributed in the hope that it will be useful,         */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
+/*  GNU General Public License for more details.                          */
+/*                                                                        */
+/*  You should have received a copy of the GNU General Public License     */
+/*  along with Evolvotron.  If not, see <http://www.gnu.org/licenses/>.   */
+/**************************************************************************/
 
 /*! \file 
   \brief Interface for class XY.
@@ -29,7 +30,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 class XY
 {
  protected:
-  real rep[2];
+  boost::array<real,2> _rep;
 
  public:
 
@@ -37,20 +38,20 @@ class XY
   //! Accessor.
   real x() const
     {
-      return rep[0];
+      return _rep[0];
     }
   real y() const
     {
-      return rep[1];
+      return _rep[1];
     }
 
   void x(real v)
     {
-      rep[0]=v;
+      _rep[0]=v;
     }
   void y(real v)
     {
-      rep[1]=v;
+      _rep[1]=v;
     }
   //@}
 
@@ -63,15 +64,15 @@ class XY
   //! Copy constructor.
   XY(const XY& v)
     {
-      rep[0]=v.rep[0];
-      rep[1]=v.rep[1];
+      _rep[0]=v._rep[0];
+      _rep[1]=v._rep[1];
     }
   
   //! Initialise from separate components.
   XY(real vx,real vy)
     {
-      rep[0]=vx;
-      rep[1]=vy;
+      _rep[0]=vx;
+      _rep[1]=vy;
     }
 
   //! Trivial destructor.
@@ -81,22 +82,22 @@ class XY
   //! Subtract a vector
   void operator-=(const XY& v)
     {
-      rep[0]-=v.rep[0];
-      rep[1]-=v.rep[1];
+      _rep[0]-=v._rep[0];
+      _rep[1]-=v._rep[1];
     }
 
   //! Add a vector
   void operator+=(const XY& v)
     {
-      rep[0]+=v.rep[0];
-      rep[1]+=v.rep[1];
+      _rep[0]+=v._rep[0];
+      _rep[1]+=v._rep[1];
     }
 
   //! Multiply by scalar
   void operator*=(real k)
     {
-      rep[0]*=k;
-      rep[1]*=k;
+      _rep[0]*=k;
+      _rep[1]*=k;
     }
 
   //! Divide by scalar.
