@@ -1,20 +1,21 @@
-// Source file for evolvotron
-// Copyright (C) 2007 Tim Day
-/*
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*/
+/**************************************************************************/
+/*  Copyright 2009 Tim Day                                                */
+/*                                                                        */
+/*  This file is part of Evolvotron                                       */
+/*                                                                        */
+/*  Evolvotron is free software: you can redistribute it and/or modify    */
+/*  it under the terms of the GNU General Public License as published by  */
+/*  the Free Software Foundation, either version 3 of the License, or     */
+/*  (at your option) any later version.                                   */
+/*                                                                        */
+/*  Evolvotron is distributed in the hope that it will be useful,         */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
+/*  GNU General Public License for more details.                          */
+/*                                                                        */
+/*  You should have received a copy of the GNU General Public License     */
+/*  along with Evolvotron.  If not, see <http://www.gnu.org/licenses/>.   */
+/**************************************************************************/
 
 /*! \file 
   \brief Interface for class XYZ.
@@ -31,7 +32,7 @@ class Random01;
 class XYZ
 {
  protected:
-  real rep[3];
+  boost::array<real,3> _rep;
 
  public:
 
@@ -39,15 +40,15 @@ class XYZ
   //! Accessor.
   real x() const
     {
-      return rep[0];
+      return _rep[0];
     }
   real y() const
     {
-      return rep[1];
+      return _rep[1];
     }
   real z() const
     {
-      return rep[2];
+      return _rep[2];
     }
   const XY xy() const
     {
@@ -56,15 +57,15 @@ class XYZ
 
   void x(real v)
     {
-      rep[0]=v;
+      _rep[0]=v;
     }
   void y(real v)
     {
-      rep[1]=v;
+      _rep[1]=v;
     }
   void z(real v)
     {
-      rep[2]=v;
+      _rep[2]=v;
     }
   //@}
 
@@ -77,25 +78,25 @@ class XYZ
   //! Copy constructor.
   XYZ(const XYZ& v)
     {
-      rep[0]=v.rep[0];
-      rep[1]=v.rep[1];
-      rep[2]=v.rep[2];
+      _rep[0]=v._rep[0];
+      _rep[1]=v._rep[1];
+      _rep[2]=v._rep[2];
     }
 
   //! Initialise from an XY and a z component.
   XYZ(const XY& p,real vz)
     {
-      rep[0]=p.x();
-      rep[1]=p.y();
-      rep[2]=vz;
+      _rep[0]=p.x();
+      _rep[1]=p.y();
+      _rep[2]=vz;
     }
   
   //! Initialise from separate components.
   XYZ(real vx,real vy,real vz)
     {
-      rep[0]=vx;
-      rep[1]=vy;
-      rep[2]=vz;
+      _rep[0]=vx;
+      _rep[1]=vy;
+      _rep[2]=vz;
     }
 
   //! Trivial destructor.
@@ -105,25 +106,25 @@ class XYZ
   //! Subtract a vector
   void operator-=(const XYZ& v)
     {
-      rep[0]-=v.rep[0];
-      rep[1]-=v.rep[1];
-      rep[2]-=v.rep[2];
+      _rep[0]-=v._rep[0];
+      _rep[1]-=v._rep[1];
+      _rep[2]-=v._rep[2];
     }
 
   //! Add a vector
   void operator+=(const XYZ& v)
     {
-      rep[0]+=v.rep[0];
-      rep[1]+=v.rep[1];
-      rep[2]+=v.rep[2];
+      _rep[0]+=v._rep[0];
+      _rep[1]+=v._rep[1];
+      _rep[2]+=v._rep[2];
     }
 
   //! Multiply by scalar
   void operator*=(real k)
     {
-      rep[0]*=k;
-      rep[1]*=k;
-      rep[2]*=k;
+      _rep[0]*=k;
+      _rep[1]*=k;
+      _rep[2]*=k;
     }
 
   //! Divide by scalar.
@@ -241,6 +242,28 @@ inline const XYZ operator/(const XYZ& v,real k)
   return v*(1.0/k);
 }
 
+//! Modulus all components by 1.0
+inline const XYZ modulusf(const XYZ& p)
+{
+  return XYZ
+    (
+     modulusf(p.x(),1.0),
+     modulusf(p.y(),1.0),
+     modulusf(p.z(),1.0)
+     );
+}
+
+//! Componentwise modulus
+inline const XYZ modulusf(const XYZ& p,const XYZ& q)
+{
+  return XYZ
+    (
+     modulusf(p.x(),q.x()),
+     modulusf(p.y(),q.y()),
+     modulusf(p.z(),q.z())
+     );
+}
+
 /*! If magnitude is zero we return zero vector.
  */
 inline const XYZ XYZ::normalised() const
@@ -311,8 +334,3 @@ class RandomXYZInXYDisc : public XYZ
 };
 
 #endif
-
-
-
-
-
